@@ -3,9 +3,9 @@ macro_rules! group {
 }
 
 macro_rules! impl_native {
-    ($name:tt $from:tt) => {
-        pub fn $name(x: $from) -> f64 {
-            x as f64
+    ($name:tt $from:tt $to:tt) => {
+        pub fn $name(x: $from) -> $to {
+            x as $to
         }
     };
 }
@@ -19,11 +19,10 @@ macro_rules! impl_soft {
     };
 }
 
-macro_rules! impl_signed {
-    ($name:tt $from:tt $bits:tt $unsigned:tt) => {
-        pub fn $name(x: $from) -> f64 {
-            let s = ((x >> $bits - 1) as u64) << 63;
-            f64::from_bits($unsigned(x.wrapping_abs() as _).to_bits() | s)
+macro_rules! impl_special {
+    ($name:tt $from:tt $to:tt) => {
+        pub fn $name(x: $from) -> $to {
+            special::$name(x)
         }
     };
 }
